import 'package:flutter/material.dart';

import 'package:dynamic_color/dynamic_color.dart';
import 'package:flutter/scheduler.dart';

import 'MediumSizedContainer.dart';

void main() {
  runApp(const MainApp());
}

class MainApp extends StatelessWidget {
  const MainApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(home: DynamicColorBuilder(
        builder: (ColorScheme? lightDynamic, ColorScheme? darkDynamic) {
      final Brightness brightness =
          SchedulerBinding.instance.platformDispatcher.platformBrightness;

      final bool isDark = brightness == Brightness.dark;

      Color accentColor = (isDark
          ? (darkDynamic?.primary ?? Colors.grey.shade800)
          : (lightDynamic?.primary ?? Colors.grey.shade200));

      Color secondaryColor = (!isDark
          ? (darkDynamic?.secondary ?? Colors.red.shade800)
          : (lightDynamic?.secondary ?? Colors.blue.shade200));

      return Scaffold(
          appBar: AppBar(
              title: const Text('Inpu\'s Touch'),
              backgroundColor: secondaryColor,
              foregroundColor: isDark ? Colors.white : Colors.black),
          backgroundColor: accentColor,
          body: LayoutBuilder(builder: (context, constraints) {
            if (constraints.maxWidth > 600) {
              return MediumSizedContainer(isItVeryLargeScreen: constraints.maxWidth >= 1200,);
            }
            
            return Container(
                decoration: BoxDecoration(
                    image: DecorationImage(
                        image: AssetImage(isDark
                            ? 'assets/clock icon dark.png'
                            : 'assets/clock icon light.png'))));
          }));
    }));
  }
}
